excerpts: excerpts/main.py File Reference

excerpts

- Main Page
- Packages
- Files

- File List

All Namespaces Files Functions
Namespaces | Functions
main.py File Reference

## Namespaces
| excerpts.main

## Functions
def | excerpts.main.extract
| Extract Matching Lines. More...
def | excerpts.main.convert
| Convert Lines to Markdown. More...
def | excerpts.main.excerpt
| Extract and Convert Matching Lines. More...
def | excerpts.main.modify_path
| Modify a Path. More...